Package: quarto
Title: R Interface to 'Quarto' Markdown Publishing System
Version: 1.5.1
Authors@R: c(
    person("JJ", "Allaire", , "jj@posit.co", role = "aut",
           comment = c(ORCID = "0000-0003-0174-9868")),
    person("Christophe", "Dervieux", , "cderv@posit.co", role = c("cre", "aut"),
           comment = c(ORCID = "0000-0003-4474-2498")),
    person("Posit Software, PBC", role = c("cph", "fnd")),
    person("Gordon", "Woodhull", role = "ctb")
  )
Description: Convert R Markdown documents and 'Jupyter' notebooks to a
    variety of output formats using 'Quarto'.
License: MIT + file LICENSE
URL: https://github.com/quarto-dev/quarto-r,
        https://quarto-dev.github.io/quarto-r/
BugReports: https://github.com/quarto-dev/quarto-r/issues
Depends: R (>= 4.1.0)
Imports: cli, fs, htmltools, jsonlite, later, lifecycle, processx,
        rlang, rmarkdown, rstudioapi, tools, utils, xfun, yaml (>=
        2.3.10)
Suggests: bslib, callr, curl, dplyr, flextable, ggiraph, ggplot2, gt,
        heatmaply, kableExtra, knitr, palmerpenguins, patchwork,
        pkgload, plotly, rsconnect (>= 0.8.26), testthat (>= 3.1.7),
        thematic, tidyverse, tinytable, whoami, withr
VignetteBuilder: quarto
Config/testthat/edition: 3
Encoding: UTF-8
RoxygenNote: 7.3.2
SystemRequirements: Quarto command line tool
        (<https://github.com/quarto-dev/quarto-cli>).
NeedsCompilation: no
Packaged: 2025-09-04 13:45:05 UTC; chris
Author: JJ Allaire [aut] (ORCID: <https://orcid.org/0000-0003-0174-9868>),
  Christophe Dervieux [cre, aut] (ORCID:
    <https://orcid.org/0000-0003-4474-2498>),
  Posit Software, PBC [cph, fnd],
  Gordon Woodhull [ctb]
Maintainer: Christophe Dervieux <cderv@posit.co>
Repository: CRAN
Date/Publication: 2025-09-04 15:30:02 UTC
