# Generated by roxygen2: do not edit by hand

export(add_spin_preamble)
export(check_newer_version)
export(detect_bookdown_crossrefs)
export(find_project_root)
export(get_running_project_root)
export(has_parameters)
export(is_using_quarto)
export(new_blog_post)
export(project_path)
export(qmd_to_r_script)
export(quarto_add_extension)
export(quarto_available)
export(quarto_binary_sitrep)
export(quarto_create_project)
export(quarto_inspect)
export(quarto_list_extensions)
export(quarto_path)
export(quarto_preview)
export(quarto_preview_stop)
export(quarto_publish_app)
export(quarto_publish_doc)
export(quarto_publish_site)
export(quarto_remove_extension)
export(quarto_render)
export(quarto_serve)
export(quarto_update_extension)
export(quarto_use_template)
export(quarto_version)
export(tbl_qmd_div)
export(tbl_qmd_div_base64)
export(tbl_qmd_div_raw)
export(tbl_qmd_span)
export(tbl_qmd_span_base64)
export(tbl_qmd_span_raw)
export(theme_brand_flextable)
export(theme_brand_ggplot2)
export(theme_brand_gt)
export(theme_brand_plotly)
export(theme_brand_thematic)
export(theme_colors_flextable)
export(theme_colors_ggplot2)
export(theme_colors_gt)
export(theme_colors_plotly)
export(theme_colors_thematic)
export(write_yaml_metadata_block)
export(yaml_quote_string)
import(rlang)
importFrom(cli,cli_abort)
importFrom(cli,cli_inform)
importFrom(htmltools,div)
importFrom(htmltools,span)
importFrom(jsonlite,fromJSON)
importFrom(later,later)
importFrom(lifecycle,deprecated)
importFrom(processx,process)
importFrom(processx,run)
importFrom(rlang,caller_env)
importFrom(rlang,is_interactive)
importFrom(rmarkdown,relative_to)
importFrom(rstudioapi,isAvailable)
importFrom(rstudioapi,viewer)
importFrom(tools,vignetteEngine)
importFrom(utils,browseURL)
importFrom(xfun,base64_encode)
importFrom(xfun,env_option)
importFrom(xfun,normalize_path)
importFrom(yaml,as.yaml)
importFrom(yaml,write_yaml)
