# quarto-vscode <a href="https://posit.co"><img src="https://cdn.jsdelivr.net/gh/posit-dev/supported-by-posit/img/badge.png" width="100" alt="Supported by Posit" align="right" /></a>

A Visual Studio Code extension for the [Quarto](https://quarto.org) scientific and technical publishing system.

![](https://quarto.org/docs/tools/images/positron-python.png)

This extension provides language support for Quarto `.qmd` files for both [VS Code](https://quarto.org/docs/get-started/hello/vscode.html) and [Positron](https://quarto.org/docs/get-started/hello/positron.html).

Use the functionality provided in this extension to:

- Author Quarto documents with enhanced editing features such as syntax highlighting, code completion, diagnostics, specialized code snippets, and document navigation
- Use the Visual Editor for [WYSIWYM](https://en.wikipedia.org/wiki/WYSIWYM) editing of Quarto documents
- Execute code cells interactively
- Render and preview Quarto documents to multiple formats

## Positron

[Positron](https://positron.posit.co/) comes ready to work with Quarto out-of-the-box; it includes both the Quarto command line interface, this extension, and support for enhanced features for Python and R as embedded languages.

[Read more](https://quarto.org/docs/tools/positron/) about using Quarto with Positron, including how to author [`.ipynb` notebooks](https://quarto.org/docs/tools/positron/notebook.html).

## VS Code

To use Quarto in VS Code, install both this extension and the [Quarto command line interface](https://quarto.org/docs/get-started/). To use enhanced features for embedded languages such as completion and code execution, additionally install the VS Code extension for your language(s) of choice:

- [Python](https://marketplace.visualstudio.com/items?itemName=ms-python.python) and [Jupyter](https://marketplace.visualstudio.com/items?itemName=ms-toolsai.jupyter) (for code execution)
- [R](https://marketplace.visualstudio.com/items?itemName=REditorSupport.r)
- [Julia](https://marketplace.visualstudio.com/items?itemName=julialang.language-julia)

[Read more](https://quarto.org/docs/tools/vscode/) about using Quarto with VS Code, including how to author [`.ipynb` notebooks](https://quarto.org/docs/tools/vscode/notebook.html).

![](https://quarto.org/docs/tools/images/vscode-notebook.png)

## Getting Help

If you have questions or need help with Quarto, you can check out the [Quarto discussion forum](https://github.com/orgs/quarto-dev/discussions). If you have a bug report or feature request for this extension, you can use its [GitHub repository](https://github.com/quarto-dev/quarto).
