Generated by hand by inspecting https://github.com/jgm/pandoc/commits/main/doc/lua-filters.md

## Changelog

2024-12-19: Up to date to commit https://github.com/jgm/pandoc/commit/8c96c6e7768fbf4af8ebce1126400b7655de7a4d

Previously: Up to date to commit https://github.com/jgm/pandoc/commit/8c96c6e7768fbf4af8ebce1126400b7655de7a4d

## TODO

- decide on lua-types for https://github.com/jgm/pandoc/commit/e243cd696f97410ba7d25ffd2800936c16d160bf
