# <%= title %> Format

## Installing

_TODO_: Replace the `<github-organization>` with your GitHub organization.

```bash
quarto use template <github-organization>/<%= filesafename %>
```

This will install the format extension and create an example qmd file
that you can use as a starting place for your document.

## Using

_TODO_: Describe how to use your format.
