# <%= title %> Extension For Quarto

_TODO_: Add a short description of your extension.

## Installing

_TODO_: Replace the `<github-organization>` with your GitHub organization.

```bash
quarto add <github-organization>/<%= filesafename %>
```

This will install the extension under the `_extensions` subdirectory.
If you're using version control, you will want to check in this directory.

## Using

This extension installs a [brand.yml](https://posit-dev.github.io/brand-yml/) configuration for _your organization name_.

## Example

Here is the source code for a minimal example: [example.qmd](example.qmd).
