# <%= title %> Format

## Installing

*TODO*: Replace the `<github-organization>` with your GitHub organization.

```bash
quarto use template <github-organization>/<%= filesafename %>
```

This will install the extension and create an example qmd file that you can use as a starting place for your article.

## Using

*TODO*: Describe how to use your extension.

## Format Options

*TODO*: If your format has options that can be set via document metadata, describe them.

## Example

Here is the source code for a minimal sample document: [example.qmd](example.qmd).
