29-08-2025 - Those tests are for now ignored because they rely on a repo that is not accessible anymore. They need to be recreated, and it could take time. We don't want our test suites to be blocked by this.
