#' @keywords internal
"_PACKAGE"

## usethis namespace: start
#' @import rlang
#' @importFrom cli cli_inform
#' @importFrom htmltools div
#' @importFrom htmltools span
#' @importFrom lifecycle deprecated
#' @importFrom rlang caller_env
#' @importFrom tools vignetteEngine
#' @importFrom xfun base64_encode
#' @importFrom xfun env_option
#' @importFrom xfun normalize_path
## usethis namespace: end
NULL
