#' ---
#' title: Purl Test Document
#' format: html
#' ---
#' 

#| label: my-label
#| echo: false
#| output: asis
cat("Hello, world")

#| echo: true
cat("more")

#| eval: false
# # This code should not run.
# 1 + a


