#' ---
#' title: "A report generated from a pure R script"
#' format: html
#' ---
#'
#' This is a report generated by `knitr::spin()`.
#'
#' ## Code block {#block}
#'
#' Let's try some **knitr** options:

#| echo: false
#| fig-with: 7
#  This is a normal R comment.
plot(cars)

#' ## Inline value {#inline}
#'
#' Now write an inline value. We know the value of $\pi$ is
# /*
# fmt: skip
# */
{{ pi }}
#' .
#'
#' Finally please note that all roxygen comments are
#' optional. You do not need chunk options, either,
#' unless you want more control over the output
#' elements such as the size of plots.

# /* Write comments between /* and */ like C comments:
Sys.sleep(60)
# */
