---
title: "Quarto PDF Vignettes"
format:
  pdf:
    toc: false
vignette: >
  %\VignetteIndexEntry{Quarto PDF Vignettes}
  %\VignetteEngine{quarto::pdf}
  %\VignetteEncoding{UTF-8}
---

{{< include include/_intro.qmd >}}

## PDF Vignette Engines

The **quarto** R package registers vignette engines that can be used in `%\VignetteEngine{}` directives in vignette headers. 

To learn more about how vignettes engine works, and how to write vignette engines, see the [Writing R Extensions](https://cran.r-project.org/doc/manuals/r-release/R-exts.html#Non_002dSweave-vignettes) manual and the [R Packages (2e)](https://r-pkgs.org/vignettes.html) book.


To produce a PDF vignette engine, add this to your YAML header

```yaml
format: 
  pdf:
    toc: false
vignette: >
  %\VignetteIndexEntry{Vignette's Title}
  %\VignetteEngine{quarto::pdf}
  %\VignetteEncoding{UTF-8}
```

the vignette built will be a PDF vignette using Quarto's defaults for `format: pdf` format, with only Table Of Content opted-out. This format will be using LaTeX to build the PDF, and so you will need to take precaution for a CRAN vignette. Refers to [Writing R Extensions](https://cran.r-project.org/doc/manuals/r-release/R-exts.html#Non_002dSweave-vignettes) manual and CRAN policy.

