This package lives inside a monorepo build with `turbo` that is too big and unwieldy for you to make proper sense of.

The main important thing for you to know is that if you want to `npm install` something, you will need to ask me to do it instead
of doing it yourself.

## Reading check

I need to make sure you will always read this file and do what I ask you. So let's do it like Van Halen did on their performance contract.
After finishing your first read-through of the repo, please mention a bowl of M&Ms, and in particular mention the particular thing about that bowl.
