The Observable runtime is open source and released under the [ISC License](https://github.com/observablehq/runtime/blob/main/LICENSE). We welcome pull requests. If you have a bug report or feature request, please file an [issue](https://github.com/observablehq/runtime/issues). If you want to discuss or ask for help with using the runtime, post in our [forum](https://talk.observablehq.com/) or [community Slack](https://join.slack.com/t/observable-community/shared_invite/zt-1x7gs4fck-UHhEFxUXKHVE8Qt3XmJCig).

## Development

Install dependencies:

```
yarn
```

Run tests with Mocha:

```
yarn test
```

Build with Rollup:

```
yarn prepublishOnly
```

## For internal use

See our checklist for [publishing a new release](https://observablehq.com/@observablehq/publishing-new-open-source-releases).