---
title: Formatting TypeScript Code Cells
subtitle: https://github.com/quarto-dev/quarto/pull/655
format: html
---

```{ts}
//| label: ts-cell
//| echo: false
const x=1;
const y=2;
const z=x+y;
```
