- Item one
- Item two
- Item three

This is `inline code` text

```
function hello() {
    return "world"
}
```

This is *emphasized* text

# Main Header

Line one
Line two

[a link](./hello "out"){#fig .class key=value}

This is inline math $E = mc^2$ and more text

This is display math

$$\int_{-\infty}^{\infty} e^{-x^2} dx = \sqrt{\pi}$$

More inline math $\alpha + \beta = \gamma$ here

This is a simple paragraph

'single quote' "double quote"

a [span]{#with-id .class key=value}

~~strikeout~~

This is **strong** text

^superscript^

[underlined]{.underline} [underline]{.ul}
