# Testing equals signs in attribute values

This test document validates that equals signs in attribute values are handled correctly.

This prose contains some equals signs, just in case. A=B=C. D=E=F. =

## Basic examples

- Basic link with equals in value: [Link text](https://example.com){key="value=with=equals"}

- Link with URL parameter: [Query link](https://example.com?param=value){.class key="query=param"}

- Span with complex value: [Span text]{#id .class key="complex=value"}

- Other weird examples: [Span text](key=) [Span](===)

## More complex examples

- CSS style with equals: [Styled text]{style="color:red;font-size=12px"}

- Math expression value: [Math formula]{formula="E=mc^2"}

- Code with equals: `code sample`{lang="c++" key="value=val"}

## Code blocks

```{python key=value=equals}
print("Testing equals in attribute values")
```

```{r eval=1+1=2}
print("R code with equals in attributes")
```

## Div with attributes

::: {#div-id key="value=with=multiple=equals"}
This is a div with multiple equals signs in attribute values.
:::

## Image with equals signs

![Image caption](image.png){width="50%" height="30%" key="value=equals"}

## Table with equals signs

| Col1 | Col2 |
|------|------|
| A    | B    |
| C    | D    |

: Table caption