---
title: Formatting Python Code Cells with Multiple Options
subtitle: https://github.com/quarto-dev/quarto/pull/655
format: html
---

```{python}
#| label: multi
#| echo: false
#| warning: false
x=1;y=2;z=x+y
```
