---
title: Purl Test Document
toc-title: Table of contents
---

Hello, world

:::: cell
``` {.r .cell-code}
cat("more")
```

::: {.cell-output .cell-output-stdout}
    more
:::
::::

::: cell
``` {.r .cell-code}
# # This code should not run.
# 1 + a
```
:::
