---
format:
  html:
    quality: 1
  pdf:
    quality: 2
  typst:
    quality: 0
  dashboard:
    quality: -1
  docx:
    quality: 1
  pptx:
    quality: -1
keep-typ: true
keep-tex: true
_quarto:
  tests:
    pdf:
      ensureLatexFileRegexMatches:
      -
        - '\\hfill\\pandocbounded\{\\includegraphics\[keepaspectratio\]\{100.png\}'
      - []
    typst:
      ensureTypstFileRegexMatches:
        - []
        - []
        # testable but not working yet
        # -
        #   - "#align\\(right\\)\\[(\r\n?|\n)#box"
        # -
        #   - "#block\\[(\r\n?|\n)#align\\(right\\)\\["
---

![](100.png){#fig-1 fig-align="right"}
