---
format:
  html:
    quality: 1
  pdf:
    quality: na
  typst:
    quality: 2
    comment: "td only"
  dashboard:
    quality: 1
  docx:
    quality: na
  pptx:
    quality: na
keep-typ: true
_quarto:
  tests:
    typst:
      ensureTypstFileRegexMatches:
        -
          - 'table\.cell\(stroke: \(paint: rgb\("#4b0082cd"\)\)\)\[A\]'
        - []
---

```{=html}
<table>
    <tr><td style="border-color: #4b0082cd">A</td><td>B</td></tr>
</table>
```

