---
title: Untitled
format:
  <%= name %>-typst: default
---

## Introduction

*TODO* Create an example file that demonstrates the formatting and features of your format.

## More Information

You can learn more about creating custom Typst templates here: 

<https://quarto.org/docs/prerelease/1.4/typst.html#custom-formats>


