---
format: 
  docusaurus-md: 
    quality: 1
  pdf:
    quality: na
  html:
    quality: na
  dashboard:
    quality: na
  typst:
    quality: na
  revealjs:
    quality: na
  
---

```{=mdx}
export const Highlight = ({children, color}) => (
  <span
    style={{
      backgroundColor: color,
      borderRadius: '2px',
      color: '#fff',
      padding: '0.2rem',
    }}>
    {children}
  </span>
);
```

<Highlight color="#25c2a0">Docusaurus GREEN</Highlight> and <Highlight color="#1877F2">Rams blue</Highlight> are my favorite colors.

I can write **Markdown** alongside my _JSX_!
