---
format: 
  docusaurus-md: 
    quality: na
    comment: "not sure, did not work in codesandbox"
  pdf:
    quality: 1
  html:
    quality: 1
  dashboard:
    quality: 1
  typst:
    quality: na
  revealjs:
    quality: 1
  docx:
    quality: na
  pptx:
    quality: na
  
---

``` tex
\begin{gather*}
a_1=b_1+c_1\\
a_2=b_2+c_2-d_2+e_2
\end{gather*}

\begin{align}
a_{11}& =b_{11}&
  a_{12}& =b_{12}\\
a_{21}& =b_{21}&
  a_{22}& =b_{22}+c_{22}
\end{align}
```

```{=tex}
\begin{gather*}
a_1=b_1+c_1\\
a_2=b_2+c_2-d_2+e_2
\end{gather*}
```

```{=tex}
\begin{align}
a_{11}& =b_{11}&
  a_{12}& =b_{12}\\
a_{21}& =b_{21}&
  a_{22}& =b_{22}+c_{22}
\end{align}
```
