---
format:
  html:
    quality: 1
  pdf:
    quality: na
  typst:
    quality: 2
    comment: "td, span only"
  dashboard:
    quality: 1
  docx:
    quality: na
  pptx:
    quality: na
keep-typ: true
_quarto:
  tests:
    typst:
      ensureTypstFileRegexMatches:
        -
          - '\[#set text\(fill: rgb\(0, 0, 0, 50%\)\); B\]'
        - []
---

```{=html}
<table>
    <tr><td>A</td><td style="opacity: 50%">B</td></tr>
</table>
```

