---
format: 
  docusaurus-md: 
    quality: 1
  pdf:
    quality: 1
  html:
    quality: 1
  dashboard:
    quality: 1
  typst:
    quality: 1
  revealjs:
    quality: 1
  
---

```{=html}
<table>
 <caption>Favorite and Least Favorite Things</caption>
 <tr>
  <th></th><th></th>
  <th>Bob</th>
  <th>Alice</th>
 </tr>
 <tr>
  <th rowspan="2">Favorite</th>
  <th>Color</th>
  <td>Blue</td>
  <td>Purple</td>
 </tr>
 <tr>
  <th>Flavor</th>
  <td>Banana</td>
  <td>Chocolate</td>
 </tr>
 <tr>
  <th rowspan="2">Least Favorite</th>
  <th>Color</th>
  <td>Yellow</td>
  <td>Pink</td>
 </tr>
 <tr>
  <th>Flavor</th>
  <td>Mint</td>
  <td>Walnut</td>
 </tr>
</table>

```
