---
format: 
  docusaurus-md: {}
  html: {}
  pdf: {}
---

## Crossreferenceable Code Listings

```{#lst-customers .sql lst-cap="Customers Query"}
SELECT * FROM Customers
```

Then we query the customers database (@lst-customers).
