# Contributing

You can contribute to Quarto in many ways:

- By opening issues to provide feedback and share ideas.
- By submitting Pull Request (PR) to fix open issues
- By submitting Pull Request (PR) to suggest new features (it is considered good practice to open an issue for discussion before working on a pull request for a new feature).

Please be mindful of our [code of conduct](https://github.com/quarto-dev/quarto-cli/blob/main/.github/CODE_OF_CONDUCT.md) as you interact with other community members.

## Pull Requests

Pull requests are very welcome! Here's how to contribute via PR:

1.  [Fork](https://github.com/quarto-dev/quarto-cli/fork) the repository, clone it locally, and make your changes in a new branch specific to the PR. For example:

    ```bash
    # clone your fork
    $ git clone https://github.com/<username>/quarto-cli

    # configure for your platform (./configure.sh on mac/linux, or ./configure.cmd on windows powershell)
    $ cd quarto-cli
    $ ./configure.sh

    # checkout a new branch
    $ git checkout -b feature/newthing
    ```

2.  For significant changes (e.g., more than small bug fixes), ensure that you have signed the [individual](https://posit.co/wp-content/uploads/2023/04/2023-03-13_TC_Indiv_contrib_agreement.pdf) or [corporate](https://posit.co/wp-content/uploads/2023/04/2023-03-13_TC_Corp_contrib_agreement.pdf) contributor agreement as appropriate. You can send the signed copy to [jj\@rstudio.com](mailto:jj@rstudio.com){.email}.

3.  Submit the [pull request](https://help.github.com/articles/using-pull-requests). It is ok to submit as draft if your are still working on it but would like some feedback from us. It is always good to share in the open that you are working on it.

We'll try to be as responsive as possible in reviewing and accepting pull requests.

## AI-Assisted Development

This repository includes shared [Claude Code](https://docs.anthropic.com/en/docs/claude-code) memory files in `.claude/` that help AI assistants understand the Quarto codebase. See [dev-docs/claude-code-setup.md](dev-docs/claude-code-setup.md) for details on how these work and how to contribute to them.
