# Contributing to Quarto

We welcome contributions to Quarto!

You can contribute in many ways:

- By opening issues to provide feedback and share ideas.
- By fixing typos in documentation
- By submitting Pull Request (PR) to fix opened issues
- By submitting Pull Request (PR) to suggest new features (it is considered good practice to open an issue for discussion before working on a pull request for a new feature).

## To submit a contribution using a Pull Request

1.  [Fork](https://github.com/quarto-dev/quarto-cli/fork) the repository, clone it locally, and make your changes in a new branch specific to the PR. For example:

    ```bash
    # clone your fork
    $ git clone https://github.com/<username>/quarto-cli

    # configure for your platform (./configure.sh for linux/mac  or ./configure.cmd for Windows)
    $ cd quarto-cli
    $ ./configure.sh

    # checkout a new branch
    $ git checkout -b bugfix/myfix
    ```

2.  For significant changes (e.g more than small bug fixes), ensure that you have signed the [individual](https://posit.co/wp-content/uploads/2023/04/2023-03-13_TC_Indiv_contrib_agreement.pdf) or [corporate](https://posit.co/wp-content/uploads/2023/04/2023-03-13_TC_Corp_contrib_agreement.pdf) contributor agreement as appropriate. You can send the signed copy to <jj@rstudio.com>.

3.  Submit the [pull request](https://help.github.com/articles/using-pull-requests). It is ok to submit as a draft if you are still working on it but would like some feedback from us. It is always good to share in the open that you are working on it.

We'll try to be as responsive as possible in reviewing and accepting pull requests. Very much appreciate your contributions!
