---
format:
  html:
    quality: -1
  pdf:
    quality: na
  typst:
    quality: -1
    comment: "invalid"
  dashboard:
    quality: -1
  docx:
    quality: na
  pptx:
    quality: na
keep-typ: true
_quarto:
  tests:
    typst:
      ensureTypstFileRegexMatches:
        -
          - '  \[A\], \[B\]'
        - []
---

```{=html}
<table>
    <tr><td style="border-width: 1pt 2pt 3pt 4pt 5pt">A</td><td>B</td></tr>
</table>
```

