---
title: Equations
format:
  docusaurus-md: default
  html: default
_quarto:
  tests:
    run:
      skip: "Pandoc 3.7+ removes newlines in display math blocks (fixed in pandoc@8123be6, awaiting release)"
    html:
      ensureHtmlElements:
        - []
        - []
    docusaurus-md:
      ensureFileRegexMatches:
        - ["^\\$\\$", "^price = \\\\hat"]
---

$$
price = \hat{\beta}_0 + \hat{\beta}_1 \times area + \epsilon
$$

Inline equations as well: $e = mc^2$.