---
title: Callouts
format:
  html: 
    quality: 2
_quarto:
  tests:
    html:
      ensureHtmlElements:
        - 
          - "div.callout-header.collapsed ~ div#callout-1.collapse"
          - "div.callout-header:not(.collapsed) ~ div#callout-2.collapse.show"
---

::: {.callout-note collapse="true"}

## A small note

You should note that this is a note.

:::

::: {.callout-note collapse="false"}

## A small note

You should note that this is a note.

:::
