---
title: Callout with no type
format:
  html: 
    quality: 2
_quarto:
  tests:
    html:
      ensureHtmlElements:
        -
          - "div.callout.callout-none"
          - "div.callout.callout-style-simple"
          - "div.callout.no-icon"
---

::: {.callout}

## Title

{{< lipsum 1 >}}

:::