---
format:
  html:
    quality: 1
  markdown:
    quality: 1
  pdf:
    quality: 1
  typst:
    quality: 0
    comment: "Extraneous line break on callout title."
  docusaurus-md:
    quality: -1
    comment: "We are not emitting the surrounding div with the anchor."
  revealjs:
    quality: 1
  dashboard:
    quality: 1
  beamer:
    quality: 1
  ipynb:
    quality: -1
    comment: "We are not emitting the surrounding div with the anchor."
---

::: {#nte-1 .callout-note}

This is a note that can be crossreferenced.

:::

See @nte-1.

