---
title: Listings Test
format: latex
_quarto:
  tests:
    latex:
      ensureFileRegexMatches:
        - [Shaded]
        - []
---

```{#lst-customers .sql lst-cap="Customers Query"}
SELECT * FROM Customers
```

Then we query the customers database (@lst-customers).