---
title: Legacy Logo Syntax with Dark/Light Mode
format:
  dashboard: default
  revealjs: default
  typst:
    output-ext: typ
brand:
  logo:
    images:
      light-logo:
        path: light-logo.png
        alt: light logo
      dark-logo:
        path: dark-logo.png
        alt: dark logo
    small:
      light: light-logo
      dark: dark-logo
# Using legacy syntax (simple string) for logo
logo: legacy-logo.svg
_quarto:
  tests:
    dashboard:
      ensureHtmlElements:
        -
          # Legacy syntax should apply to both light and dark modes
          - 'img[src="legacy-logo.svg"][alt=""][class="navbar-logo light-content d-inline-block"]'
          - 'img[src="legacy-logo.svg"][alt=""][class="navbar-logo dark-content d-inline-block"]'
        - []
    revealjs:
      ensureHtmlElements:
        -
          - 'img[src="legacy-logo.svg"]:not([alt])'
        - []
    typst:
      ensureTypstFileRegexMatches:
        -
          - 'background: align\(left\+top, box\(inset: 0.75in, image\("legacy-logo.svg", width: 1\.5in\)\)'
        - []
---

{{< lipsum 4 >}}