---
title: "Welcome To My Blog"
author: "Tristan O'Malley"
date: "2024-10-20"
categories: [news]
---

This is the first post in a Quarto blog. Welcome!

![](thumbnail.jpg)

Since this post doesn't specify an explicit `image`, the first image in the post will be used in the listing page of posts.
