---
title: Document Title
author:
  - name: Charles Teague
    affiliation: Macalester College
date: 2020/05/21
abstract: |
  Just so you know, i am always playing your covers in my restaurant. Its snowing now, everything is calm. Everyone is quiet, drinking their teas and coffees. Fire is burning and the woods are cracking. The river flows below and everyone is looking outside the window. Your covers bring memories to people, it makes them think about life. You sir are not only playing a guitar, you are hitting every single note in our minds. Thank you for your hard work and dedication.
google-scholar: true
citation:
  container-title: Container Title
  container-title-short: "C. Title."
  citation-key: Teague2020
  isbn: 123123-123131
  issn: 12313-12312-23
  issue: 53
  issued: 2021/05/23
  volume: 1
  number: 7
  page: 23-29
  type: report
  DOI: 10-12312-123
  editor:
    - Don Draper
  abstract-url: https://www.google.org/abstract
  public-url: https://www.quarto.org/public
  pdf-url: https://www.quarto.org/public/pdf
  fulltext-url: https://www.quarto.org/fulltext
  collection-title: foo
  keyword: 'foo, bar'
bibliography: "`r 'references.bib'`"
engine: knitr
---

## this is a test document

Note that @adami2020 is a pretty sweet article.