---
title: "Captions"
format: gfm
_quarto:
  tests:
    gfm:
      ensureFileRegexMatches:
        - []
        - ["<figure>"]
---

![Caption](elephant.png)

[![Caption](elephant.png)](https://quarto.org)
