---
title: Listings Test
_quarto:
  tests:
    revealjs:
      ensureHtmlElements:
        - 
          - "div#lst-customers figure.quarto-float-lst figcaption.quarto-float-lst"
          - "a[href='#/lst-customers'].quarto-xref"
        - []
---

```{#lst-customers .sql lst-cap="Customers Query"}
SELECT * FROM Customers
```

Then we query the customers database (@lst-customers).