---
title: Crossref Test
---

## Simple Figure

![Elephant](img/thinker.jpg){#fig-elephant}

See @fig-elephant for an illustration

<!--

## Simple Sub Figure

::: {#fig-elephants layout-ncol=2}

![Surus](img/surus.jpg){#fig-surus}

![Abbas](img/abbas.jpg){#fig-abbas}

Famous Elephants
:::

See @fig-elephants for examples. In particular, @fig-abbas.

-->

## Simple Crossref Table

| Col1 | Col2 | Col3 |
| ---- | ---- | ---- |
| A    | B    | C    |
| E    | F    | G    |
| A    | G    | G    |

: My Caption {#tbl-letters}

See @tbl-letters.

<!--

## Sub tables

::: {#tbl-panel layout-ncol=2}
| Col1 | Col2 | Col3 |
|------|------|------|
| A    | B    | C    |
| E    | F    | G    |
| A    | G    | G    |

: First Table {#tbl-first}

| Col1 | Col2 | Col3 |
|------|------|------|
| A    | B    | C    |
| E    | F    | G    |
| A    | G    | G    |

: Second Table {#tbl-second}

Main Caption
:::

See @tbl-panel for details, especially @tbl-second.

-->

## Math

::: {#thm-line}

## Line

The equation of any straight line, called a linear equation, can be written as:

$$
y = mx + b
$$

:::

See @thm-line.
