---
title: Knitr Crossref Test
keep-typ: true
format: typst
_quarto:
  tests:
    typst:
      ensureTypstFileRegexMatches:
        - 
          - "Plot"
          - "#ref\\(<fig-plot>, supplement: \\[Figure\\]\\)"
---

## Knitr Crossref Figure

```{r}
#| label: fig-plot
#| fig-cap: "Plot"

plot(cars)
```

For example, see @fig-plot.