---
title: Document Light Logo + Brand Light Logo Only
format:
  dashboard:
    theme:
      light: default
      dark: darkly  # Explicitly enable dark mode
    # Document level logo with only light defined
    logo:
      light: direct-light-logo.png
  revealjs:
    logo:
      light: revealjs-light-logo.png
  typst:
    output-ext: typ # refers to unknown pngs
    logo:
      light: typst-light-logo.png
brand:
  color:
    foreground: 
      light: '#222'
      dark: '#eee'
    background:
      light: '#eee'
      dark: '#222'
  logo:
    images:
      brand-light-logo:
        path: quarto.png
        alt: brand light logo
    medium:
      light: brand-light-logo
      # No dark variant defined in brand
brand-mode: dark
_quarto:
  tests:
    dashboard:
      ensureHtmlElements:
        -
          # Light mode should use document-level light logo (not brand)
          - 'img[src="direct-light-logo.png"][alt=""][class="navbar-logo light-content d-inline-block"]'
          # For dark mode, should use same document-level light logo for fallback
          - 'img[src="direct-light-logo.png"][alt=""][class="navbar-logo dark-content d-inline-block"]'
        - []
    revealjs:
      ensureHtmlElements:
        -
          - 'img[src="revealjs-light-logo.png"]:not([alt])'
        - []
    typst:
      ensureTypstFileRegexMatches:
        -
          - 'background: align\(left\+top, box\(inset: 0.75in, image\("typst-light-logo.png", width: 1\.5in\)\)'
        - []
---

{{< lipsum 4 >}}