---
title: lst-cap-location-test
_quarto:
  tests:
    docx:
      ensureDocxXpath:
        -
          - "//w:hyperlink[@w:anchor=\"lst-customers\"]"
          - "//w:hyperlink[@w:anchor=\"lst-customers-2\"]"
          - "//w:p//w:r//w:t[contains(text(), \"Listing\u00a01\")]"
          - "//w:p//w:r//w:t[contains(text(), \"Listing\u00a02\")]"
---

```{#lst-customers .sql lst-cap="Customers _query_"}
SELECT * FROM Customers
```

Then we query the customers database (@lst-customers).


```{#lst-customers-2 .sql lst-cap="Customers _query_" lst-cap-location="bottom"}
SELECT * FROM Customers
```

Then we query the customers database again (@lst-customers-2), with a caption in a different location.
