---
title: intro
_quarto:
  tests:
    html:
      ensureHtmlElements:
        -
          - 'img[class*="light-content"][src="./sun-face.png"][alt="SUN FACE"]'
          - 'img[class*="dark-content"][src="./moon-face.png"][alt="MOON FACE"]'
        - []
---
