---
title: "About"
_quarto:
  tests:
    html:
      ensureLlmsMdExists: true
      ensureLlmsMdRegexMatches:
        # First array: patterns that MUST match
        - ["^# About", "> \\*\\*NOTE:\\*\\*", "> \\*\\*WARNING:\\*\\*", "This is a note", "``` python", "def hello", "\\| Feature", "\\|[-]+\\|", "\\[home page\\]\\(.*\\.llms\\.md\\)", "\\[test site intro\\]\\(index\\.llms\\.md#test-content\\)", "## Alpha Tab", "Alpha content here", "## Beta Tab", "Beta content here", "https://pandoc.org/lua-filters.html", "https://www.lua.org/manual/5.3/manual.html#6.4"]
        # Second array: patterns that must NOT match (no internal .html links, no breadcrumbs, no empty tab links)
        - ["\\(index\\.html\\)", "\\(index\\.html#", "\\[Info\\]", "\\[Alpha Tab\\]\\(\\)", "\\[Beta Tab\\]\\(\\)"]
---

About this test site.

## Callout Examples

::: {.callout-note}
This is a note about the llms-txt feature.
:::

::: {.callout-warning}
Be careful with this setting!
:::

## Code Example

```{python}
#| eval: false
def hello():
    print("Hello, world!")
```

## Table Example

| Feature | Status |
|---------|--------|
| Callouts | Working |
| Code | Working |
| Tables | Working |

## Tabset Example

::: {.panel-tabset}

## Alpha Tab

Alpha content here.

## Beta Tab

Beta content here.

:::

## Link Example

Go back to the [home page](index.qmd).

Go to the [test site intro](index.qmd#test-content).

## External Link Example

Check out [Pandoc filters](https://pandoc.org/lua-filters.html) for more info.

See the [Lua manual](https://www.lua.org/manual/5.3/manual.html#6.4) for string functions.
