---
title: "MEW"
# FIXME: 2023-10-16, removing this format block from our suite
#     because it hangs github action's CI intermittently;
#     The test passes locally, and we don't understand it.
#
# format:
#   pdf:
#     pdf-engine: latexmk
#     pdf-engine-opts: ["-pdflua"]
---

## Quarto

Quarto enables you to weave together content and executable code into a finished document.
To learn more about Quarto see <https://quarto.org>.

```{r}
1 + 1
```