---
title: issue-7187
_quarto:
  tests:
    html:
      ensureHtmlElements:
        - []
        - ["table[data-quarto-postprocess]", "div[data-html-table-processing]"]
---

```{r}
#| html-table-processing: none
#| echo: false
knitr::kable(cars, format = "html")
```

