---
title: brand font - title is `#context text.font`{=typst} `#context text.size`{=typst}
subtitle: subtitle is the same except `#context text.size`{=typst}
format: typst
include-in-header:
  text: |
    #set text(fallback: false)
_quarto:
  tests:
    typst:
      ensurePdfRegexMatches:
      -
        - 'brand font - title is libertinus serif 16.5pt'
        - 'heading-2 is libertinus serif 15.4pt'
        - 'paragraph is libertinus serif 11pt'
        - 'fib = num => num < 2'
      -
        - 'text with font set'
---

## heading-2 is `#context text.font`{=typst} `#context text.size`{=typst}

paragraph is `#context text.font`{=typst} `#context text.size`{=typst}.

Here is some inline code: `fib(5)`

```
const fib = num => num < 2 ? num : fib(num-1) + fib(num - 2);
console.log(fib(12))
```

{{< lipsum 5 >}}

