---
title: brand-mode and logos
format:
  revealjs: default
  typst:
    keep-typ: true
brand:
  logo:
    medium:
      light: sun-face.png
      dark: moon-face.png
  color:
    foreground: 
      light: '#222'
      dark: '#eee'
    background:
      light: '#eee'
      dark: '#222'
  typography:
    headings:
      color:
        light: '#429'
        dark: '#54e'
brand-mode: light
_quarto:
  tests:
    revealjs:
      ensureHtmlElements:
        -
          - 'img[src="sun-face.png"]'
        -
          - 'img[src="moon-face.png"]'
    typst:
      ensureTypstFileRegexMatches:
        -
          - 'background: align\(left\+top, box\(inset: 0.75in, image\("/sun-face\.png", width: 1\.5in\)\)'
        -
          - 'background.*moon-face\.png'
---

## Here we go

- in {{< meta brand-mode >}} mode!
