---
title: "test"
format: html 
fig-align: right
_quarto:
  tests:
    html:
      ensureHtmlElements:
        - 
          - 'div[data-layout-align="left"]'
          - 'div[data-layout-align="center"]' # these two elements cause our mermaid runtime to create div.quarto-figure-*
          - "div.quarto-figure-right"
---

```{mermaid}
%%| fig-align: left
flowchart TB
a --> b 
b --> c
```

```{mermaid}
%%| fig-align: center
%%| fig-cap: A caption
flowchart TB
a --> b 
b --> c
```


```{mermaid}
%%| fig-cap: A caption
%%| label: fig-1
flowchart TB
a --> b 
b --> c
```