---
# I think asciidoc doesn't support custom crossref prefixes, so we're not testing anything here.
title: "My Document"
format: asciidoc
crossref:
  fig-prefix: F.   # (default is "fig.")
  tbl-prefix: T.    # (default is "tbl.")
  title-delim: —     # (default is ":")
  ref-hyperlink: false # (default is true)
# _quarto:
#   tests:
#     html:
#       ensureHtmlElements:
#         - []
#         - 
#           - "a[href='#tbl-1'].quarto-xref" # ref-hyperlink: false
#       ensureFileRegexMatches:
#         - 
#           - "Figure&nbsp;1— Elephant"
#           - "See T.&nbsp;1."
#           - "See F.&nbsp;1."
---

# Introduction

![Elephant](img/painter.jpg){#fig-elephant}

See @fig-elephant for an illustration.


| Col1 | Col2 | Col3 |
|------|------|------|
| A    | B    | C    |
| E    | F    | G    |
| A    | G    | G    |

: My Caption {#tbl-letters}

See @tbl-letters.