---
title: float test
format: typst
keep-typ: true
_quarto:
  tests:
    typst:
      ensureTypstFileRegexMatches:
        -
          - "#ref\\(<tbl-foo>, supplement: \\[Table\\]\\)"
          - "#ref\\(<fig-foo>, supplement: \\[Figure\\]\\)"
          # Images with captions now include alt text for accessibility
          - '#link\("https://www\.example\.com/"\)\[#box\(image\("img/surus\.jpg", alt:'
---

This tests:

- float syntax for implicit figures and tables as linked images with identifiers

[![This is the figure](img/surus.jpg){#fig-foo}](https://www.example.com/)

[![This is the table](img/surus.jpg){#tbl-foo}](https://www.example.com/)

See @fig-foo and @tbl-foo for more.