---
format:
  typst:
    keep-typ: true
_quarto:
  tests:
    html:
      ensureHtmlElements:
        - 
          - "a.quarto-xref"
        - []
    latex:
      ensureFileRegexMatches:
        -
          - "\\\\begin{theorem}\\[Line\\]"
          - "hypertarget{thm-line}"
          - "label{thm-line}"
          - "Theorem~\\\\ref\\{thm-line\\}"
        - []
    typst:
      ensureTypstFileRegexMatches:
        -
          - "#ref\\(<thm-line>, supplement: \\[Theorem\\]\\)"
          - "#theorem\\(title: \"Line\"\\)"
          - "#import \"@preview/theorion:0\\.4\\.1\": make-frame"
          - "simple-theorem-render"
        -
          - "cosmos"
          - "fancy-box"
    markdown:
      ensureFileRegexMatches:
        -
          - "\\[Theorem 1\\]\\(#thm-line\\)\\{.quarto-xref\\}"
          - '\[\*\*Theorem 1 \(Line\)\*\*\]\{.theorem-title\}'
    

---

::: {#thm-line}

## Line

The equation of any straight line, called a linear equation, can be written as:

$$
y = mx + b
$$
:::

See @thm-line.
