---
title: brand and base logo
format:
  dashboard: default
  revealjs: default
  typst:
    output-ext: typ
brand:
  logo:
    images:
      quarto:
        path: quarto.png
        alt: quarto logo
      posit:
        path: posit-logo-2024.svg
        alt: posit logo
    medium: quarto
    large: posit
logo:
  path: large
  alt: logo of posit
_quarto:
  tests:
    dashboard:
      ensureHtmlElements:
        -
          - 'img[src="posit-logo-2024.svg"][alt="logo of posit"]'
        - []
    revealjs:
      ensureHtmlElements:
        -
          - 'img[src="posit-logo-2024.svg"][alt="logo of posit"]'
        - []
    typst:
      ensureTypstFileRegexMatches:
        -
          - 'background: align\(left\+top, box\(inset: 0.75in, image\("/posit-logo-2024.svg", width: 1\.5in, alt: "logo of posit"\)\)'
        - []
---

{{< lipsum 4 >}}