---
_quarto:
  render-project: true
  tests:
    html:
      ensureFileRegexMatches:
        - []
        - ["\\<span\\>This is a caption\\.\\<\\/span\\>"]
---

# Preface {.unnumbered}

This is a Quarto book.

To learn more about Quarto books visit <https://quarto.org/docs/books>.

See @fig-1 for more.