---
title: "Axe Accessibility - Revealjs"
format:
  revealjs:
    axe: true
_quarto:
  tests:
    revealjs:
      ensureHtmlElements:
        - ['script[src*="axe-check"]', '#quarto-axe-checker-options']
        - []
      ensureFileRegexMatches:
        - ['quarto-axe-checker-options']
        - []
---

## Slide 1

Content for accessibility checking.

## Slide 2

More content.
