---
title: issue-6568
keep-md: true
_quarto:
  tests:
    html:
      ensureFileRegexMatches:
        - []
        - ["AAAAAElFTkSuQmCC\\.png"]
---

Output of `image(volcano)` in Base64:

quartz_off_screen
2
![](data:image/png;base64,[encoded data, 21976 characters])
