---
title: "About"
image: profile.jpg
about:
  template: jolla
  links:
    - icon: bluesky
      text: Bluesky
      href: https://bsky.app
    - icon: linkedin
      text: LinkedIn
      href: https://linkedin.com
    - icon: github
      text: Github
      href: https://github.com

---

About this blog
