---
format: latex
title: "Long Table kable fixups etc"
_quarto:
  tests:
    latex:
      ensureFileRegexMatches:
        - 
          - "\\label{tbl-test}"
        - []
---

```{r}
#| warning: false
#| output: false
#| echo: false
library(knitr)
library(tidyverse)
```

```{r}
#| echo: false
#| label: tbl-test
df <- tibble(
  x = 1:20,
  y = rnorm(20),
  z = rnorm(20)
)
kable(df,
  format = "latex",
  longtable = TRUE,
  booktabs = TRUE,
  caption = "A long table with a caption"
)
```

See @tbl-test.
