---
title: float crossref test
format: html
_quarto:
  tests:
    revealjs:
      ensureHtmlElements:
        - 
          - "div#tbl-foo figure.quarto-float-tbl img"
          - "div#fig-foo figure.quarto-float-fig img"
          - "a[href='#/fig-foo'].quarto-xref"
          - "a[href='#/tbl-foo'].quarto-xref"
---

This tests:

- div float with image element as payload.
- div float with image element as payload for non-figure floats.


::: {#fig-foo}
![](img/surus.jpg)

This is the figure
:::
See @fig-foo for more.


::: {#tbl-foo}
![](img/surus.jpg)

This is the table
:::
See @tbl-foo for more.

