---
title: "empty floats"
format: latex
_quarto:
  tests:
    latex:
      noErrors: true
---

:::{#fig-1}

:::{.content-hidden when-format="latex"}
![A sub-caption](an-image.png){#fig-1-1}
:::

:::{.content-hidden when-format="latex"}
![A sub-caption](an-image.png){#fig-1-2}
:::

A caption.
:::


