---
title: "Pandoc Latex"
author: "Charles Teague"
date: "1/21/2021"
output: html_document
knit: quarto render
format: pdf
header-includes: |
  \usepackage{makeidx}
  \makeindex
validate: false
---

# Document with Index

This document will result in an index \index{Raw Index} being generated.

\newpage

# It's Cool, Right?

It is a cool index \index{Cool Index} right?

\newpage

\printindex
