---
title: float crossref test
format: revealjs
_quarto:
  tests:
    revealjs:
      ensureHtmlElements:
        - 
          - "div#tbl-foo figure.quarto-float-tbl img"
          - "div#fig-foo figure.quarto-float-fig img"
          - "a[href='#/fig-foo'].quarto-xref"
          - "a[href='#/tbl-foo'].quarto-xref"
---

This tests:

- float syntax for implicit figures and tables as images with identifiers

![This is a figure](img/surus.jpg){#fig-foo}

![This is a table](img/surus.jpg){#tbl-foo}

See @fig-foo and @tbl-foo for more.