---
_quarto:
  tests:
    html:
      ensureFileRegexMatches:
        - ['<link href="./logos/small.png" rel="icon" type="image/png">']
        - []
---

# Preface {.unnumbered}

This is a Quarto book.

To learn more about Quarto books visit <https://quarto.org/docs/books>.
