---
format: html
_quarto:
  tests:
    html:
      ensureHtmlElements:
        - ["div.table-responsive"]
---

## Wide Markdown table

| CODICE_CUP | CODICE_TEMATICA | NOME_TEMATICA | CODICE_TEMPLATE | DESCRIZIONE_TEMPLATE | CODI_CODICE_NATURA | DESC_DESCRIZIONE_NATURA | CODI_CODICE_TIPOLOGIA | DESC_DESCRIZIONE_TIPOLOGIA | DESCRIZIONE_AGGREGATA | SOGGETTO_TITOLARE | PIVA_SOGGETTO | UNITA_ORGANIZZATIVA | STRUMENTO_PROGRAMMAZIONE | CODICE_STATO | STATO | CODI_CODICE_REGIONE | REGIONE | CODI_CODICE_PROVINCIA | PROVINCIA | CODI_CODICE_COMUNE | COMUNE | CODICE_SETTORE_INTERVENTO | SETTORE_INTERVENTO | CODICE_SOTTOSETTORE_INTERVENTO | SOTTOSETTORE_INTERVENTO | CODICE_CATEGORIA_INTERVENTO | CATEGORIA_INTERVENTO | ANNO_DECISIONE | DATA_GENERAZIONE_COMPLETO | IMPO_COSTO_PROGETTO | IMPO_IMPORTO_FINANZIATO | STATO_PROGETTO | TIPO_PROGETTO | TAG_DATA_FINE_VALIDITA |
| --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- |
| G19J22001290007 | 528 | M6C2: Innovazione, ricerca e digitalizzazione del servizio sanitario - I1.1:Ammodernamento del parco tecnologico e digitale ospedaliero |  |  | 01 | ACQUISTO DI BENI | 00 | NUOVA FORNITURA | A.O.U. CITTA' DELLA SALUTE E DELLA SCIENZA DI TORINO*CORSO BRAMANTE 88/90*SISTEMI POLIFUNZIONALI PER RADIOLOGIA DIGITALE DIRETTA (DR) _OSPEDALE SAN GIOVANNI BATTISTA MOLINETTE_10 | AZIENDA OSPEDALIERA CITTA' DELLA SALUTE E DELLA SCIENZA | 10771180014 | S.C. PROVVEDITORATO/ECONOMATO | PIANO NAZIONALE DI RIPRESA E RESILIENZA_x000D_
 | 5 | ITALIA | 01 | PIEMONTE | 001 | TORINO | 001272 | TORINO | 05 | INFRASTRUTTURE SOCIALI | 30 | SANITARIE | 111 | STRUTTURE OSPEDALIERE | 2022 | 2022-02-17 | 244000 | 244000 | Attivo | Progetto Normale |  |
| J61F22002840006 | 400 | M1C1: Digitalizzazione, innovazione e sicurezza nella PA - I1.4:Servizi digitali e esperienza dei cittadini | 2205010 | PCM - Dipartimento per la trasformazione digitale - PNRR M1C1 investimento 1.4 "servizi e cittadinanza digitale, misura 1.4.3  adozione piattaforma pagoPA- ALTRI ENTI | 02 | ACQUISTO O REALIZZAZIONE DI SERVIZI | 19 | APPLICATIVI E PIATTAFORME WEB | PIATTAFORMA PAGOPA*TERRITORIO NAZIONALE*ATTIVAZIONE SERVIZI | REGIONE PIEMONTE | 80087670016 | SETTORE SISTEMA INFORMATIVO REGIONALE | PNRR MISSIONE 1 COMPONENTE 1 INVESTIMENTO1.4 "SERVIZI E CITTADINANZA DIGITALE", MISURA 1.4.3 "ADOZIONE PIATTAFORMA PAGOPA" | 5 | ITALIA | 01 | PIEMONTE |  |  |  |  | 10 | SERVIZI PER LA P.A. E PER LA COLLETTIVITA' | 02 | SERVIZI E APPLICAZIONI INFORMATICHE PER I CITTADINI E LE IMPRESE | 001 | SERVIZI ED APPLICAZIONI PER IL PUBBLICO | 2022 | 2022-09-13 | 297328 | 297328 | Attivo | Progetto Normale |  |
| G19J22001350007 | 529 | M6C2: Innovazione, ricerca e digitalizzazione del servizio sanitario - I1.2:Verso un ospedale sicuro e sostenibile |  |  | 01 | ACQUISTO DI BENI | 00 | NUOVA FORNITURA | A.O.U. CITTA' DELLA SALUTE E DELLA SCIENZA DI TORINO*CORSO BRAMANTE 88/90*MULTIDISCIPLINARI/INTERNISTICI _ OSPEDALE SAN GIOVANNI BATTISTA MOLINETTE_17 | AZIENDA OSPEDALIERA CITTA' DELLA SALUTE E DELLA SCIENZA | 10771180014 | S.C. PROVVEDITORATO/ECONOMATO | PIANO NAZIONALE DI RIPRESA E RESILIENZA_x000D_
 | 5 | ITALIA | 01 | PIEMONTE | 001 | TORINO | 001272 | TORINO | 05 | INFRASTRUTTURE SOCIALI | 30 | SANITARIE | 111 | STRUTTURE OSPEDALIERE | 2022 | 2022-02-17 | 82000 | 82000 | Attivo | Progetto Normale |  |
| J61F22002850006 | 400 | M1C1: Digitalizzazione, innovazione e sicurezza nella PA - I1.4:Servizi digitali e esperienza dei cittadini | 2205009 | PCM - Dipartimento per la trasformazione digitale - PNRR M1C1  Investimento 1.4 Servizi e cittadinanza digitale Sub-investimento 1.4.3 Adozione APP IO - ALTRI ENTI | 02 | ACQUISTO O REALIZZAZIONE DI SERVIZI | 19 | APPLICATIVI E PIATTAFORME WEB | APPLICAZIONE APP IO*TERRITORIO NAZIONALE*ATTIVAZIONE SERVIZI | REGIONE PIEMONTE | 80087670016 | SETTORE SISTEMA INFORMATIVO REGIONALE | PNRR MISSIONE 1 COMPONENTE 1 INVESTIMENTO1.4 "SERVIZI E CITTADINANZA DIGITALE", MISURA 1.4.3 "ADOZIONE APP IO". | 5 | ITALIA | 01 | PIEMONTE |  |  |  |  | 10 | SERVIZI PER LA P.A. E PER LA COLLETTIVITA' | 02 | SERVIZI E APPLICAZIONI INFORMATICHE PER I CITTADINI E LE IMPRESE | 001 | SERVIZI ED APPLICAZIONI PER IL PUBBLICO | 2022 | 2022-09-13 | 297320 | 297320 | Attivo | Progetto Normale |  |
| G19J22001360007 | 528 | M6C2: Innovazione, ricerca e digitalizzazione del servizio sanitario - I1.1:Ammodernamento del parco tecnologico e digitale ospedaliero |  |  | 01 | ACQUISTO DI BENI | 00 | NUOVA FORNITURA | A.O.U. CITTA' DELLA SALUTE E DELLA SCIENZA DI TORINO*CORSO BRAMANTE 88/90*CARDIOLOGICI_OSPEDALE SAN GIOVANNI BATTISTA MOLINETTE_18 | AZIENDA OSPEDALIERA CITTA' DELLA SALUTE E DELLA SCIENZA | 10771180014 | S.C. PROVVEDITORATO/ECONOMATO | PIANO NAZIONALE DI RIPRESA E RESILIENZA_x000D_
 | 5 | ITALIA | 01 | PIEMONTE | 001 | TORINO | 001272 | TORINO | 05 | INFRASTRUTTURE SOCIALI | 30 | SANITARIE | 111 | STRUTTURE OSPEDALIERE | 2022 | 2022-02-17 | 82000 | 82000 | Attivo | Progetto Normale |  |

: {.striped .sm .responsive}
