---
title: Crossref Test
---

## Simple Figure

![Elephant](img/thinker.jpg){#fig-elephant}

See @fig-elephant for an illustration

## Simple Sub Figure

::: {#fig-elephants layout-ncol=2}

![Surus](img/surus.jpg){#fig-surus}

![Abbas](img/abbas.jpg){#fig-abbas}

Famous Elephants
:::

See @fig-elephants for examples. In particular, @fig-abbas.