---
format: pdf
lang: es
latex-auto-install: false
_quarto:
  tests:
    run:
      ci: false
    pdf:
      noErrors: true
      printsMessage:
        level: WARN
        regex: "Possibly missing hyphenation"
---

** This test is to be run manually as we don't want to uninstall and reinstall package in CI**

```{r}
#| include: false
#| messages: 'NA'
# Remove the hyphen package for spanish so that the test is meaningful
if (tinytex::check_installed("hyphen-spanish")) {
  message("Removing 'hyphen-spanish' package for the render")
  tinytex::tlmgr_remove("hyphen-spanish")
}
```

# Hola !

automáticamente automáticamente automáticamente automáticamente automáticamente automáticamente automáticamente automáticamente automáticamente automáticamente automáticamente automáticamente automáticamente automáticamente automáticamente automáticamente automáticamente automáticamente automáticamente automáticamente automáticamente automáticamente automáticamente automáticamente automáticamente automáticamente