---
title: test
format:
  html:
    theme: 
      - custom.scss
      - lux
#    code-fold: true
#    code-line-numbers: true
    syntax-highlighting: asa
_quarto:
  tests:
    html:
      noErrors: true
---

```r
plot(cars)
```
