---
title: "Cool Subfolder"
---

This is a Quarto website.

To learn more about Quarto websites visit <https://quarto.org/docs/websites>.

{{< embed ../notebooks/computations.ipynb#fig-visualization >}}