---
title: "Axe Accessibility - Dashboard"
format:
  dashboard:
    axe: true
_quarto:
  tests:
    dashboard:
      ensureHtmlElements:
        - ['script[src*="axe-check"]', '#quarto-axe-checker-options']
        - []
      ensureFileRegexMatches:
        - ['quarto-axe-checker-options']
        - []
---

## Row

Content for accessibility checking.

This is a regression test to ensure dashboard format works with axe enabled.
