---
title: test raw html table parsing
filters: 
 - test.lua
---

```{=html}
<table>
    <caption>Council budget (in £) 2018</caption>
    <thead>
        <tr>
            <th scope="col">Items</th>
            <th scope="col">Expenditure</th>
        </tr>
    </thead>
    <tbody>
        <tr>
            <th scope="row">Donuts</th>
            <td>3,000</td>
        </tr>
        <tr>
            <th scope="row"><span data-qmd="_process me_"></span></th>
            <td>18,000</td>
        </tr>
    </tbody>
</table>
```