---
title: "Untitled"
author: "Charles Teague"
date: "1/21/2021"
format: pdf
bibliography: references.bib
cite-method: natbib
header-includes: |
  \usepackage{fontawesome5}
  \usepackage{sansmath}
  \usepackage{makeidx}
  \makeindex
  \usepackage[french]{babel}
  \usepackage[T1]{fontenc}
  \usepackage[utf8]{inputenc}
latex-makeindex: texindy
---

# Bibliography Testing

use

    tlmgr remove hyphen-portuguese
    tlmgr remove babel-portuges

to clean this test up.

This test should install both a language and hyphenation file.

Document Language: \languagename

\faApple is an apple!

\faIcon{audio-description}

This should test bibliography \index{Bibliography} generation [@adami2020]. I also think that @allaire has a good point here, but he can also be a clown \index{Clowns} from time to time.

```{=tex}
\begin{sansmath}

$$
A^2 + B^2 = C^2
$$

\end{sansmath}
\newpage
```
# Section 2

Vestibulum \index{Latin}velit nisi, dapibus id cursus sit amet, tempor id ex. Duis gravida, dui a semper commodo, ligula mauris efficitur leo, mattis porttitor dui dolor vitae leo. Maecenas ullamcorper, nisi viverra consequat elementum, augue risus porttitor lectus, in accumsan nulla nibh id sapien. Cras augue odio, venenatis in euismod id, ultricies id lectus. Duis commodo velit elit. Sed sed finibus massa. Sed volutpat varius magna ac viverra. Aliquam a aliquam arcu, non consequat nunc. Curabitur egestas, urna vel pellentesque efficitur, elit justo viverra urna, et posuere urna nibh id purus. Praesent accumsan molestie sem, at feugiat\index{feugiat} velit aliquet ut. Integer libero felis, volutpat non eros vitae, lacinia venenatis risus.

\newpage

# Section 3

@alajlouni2020 makes a great point about things\index{things}. Vestibulum velit nisi, dapibus id cursus sit amet, tempor id ex. Duis gravida, dui a semper commodo, ligula mauris efficitur leo, mattis porttitor dui dolor vitae leo. Maecenas\index{Maecenas} ullamcorper, nisi viverra consequat elementum, augue risus porttitor lectus, in accumsan nulla nibh id sapien. Cras augue odio, venenatis in euismod id, ultricies id lectus. Duis commodo velit elit. Sed sed finibus massa. Sed volutpat varius magna ac viverra. Aliquam a aliquam arcu, non consequat nunc. Curabitur egestas, urna vel pellentesque efficitur, elit justo viverra urna, et posuere urna nibh id purus. Praesent accumsan molestie sem, at feugiat velit aliquet ut. Integer libero felis, volutpat non eros vitae, lacinia venenatis risus.

\newpage

\printindex
