---
title: test
format: html
---

## With inherited fixup

{{< include sub/include-1.md >}}

## With forced fixup

{{< include sub/include-1.md fixup=true >}}

## With no fixup

{{< include sub/include-1.md fixup=false >}}
