# Inner-1

Here is a [relative link](../link.qmd).

## inherited fixup

{{< include sub/include-2.md >}}

## forced fixup

{{< include sub/include-2.md fixup=true >}}

## forced no fixup

{{< include sub/include-2.md fixup=false >}}
