---
title: dependencies test
author: Charles Teague
filters:
  - filter.lua
_quarto:
  tests: 
    html:
      ensureHtmlElements:
        - ['script:first-of-type[src="https://cdn.jsdelivr.net/npm/jquery@3.5.1/dist/jquery.min.js"]']

---

:::{.callout-note}

This test verifies that the jquery script is properly relocated to the top of the script list so it
may be shared amongst the subsequent scripts.

:::

## A Widget

```{python}
#| label: fig-map
#| fig-cap: This is a map that is pretty cool

from ipyleaflet import Map, Marker, basemaps, basemap_to_tiles
m = Map(
  basemap=basemap_to_tiles(
    basemaps.NASAGIBS.ModisTerraTrueColorCR, "2017-04-08"
  ),
  center=(52.204793, 360.121558),
  zoom=4
)
m.add_layer(Marker(location=(52.204793, 360.121558)))
m

```