---
title: Hello World
code-annotations: select
format:
  html: default
code-line-numbers: true
_quarto:
  tests: 
    html:
      ensureHtmlElements:
        - ["button[data-target-annotation='1']"]
      ensureFileRegexMatches:
        - [".*trigger: 'click'.*"]
---

## Hi There

```typescript
const foo = "bar";
if (foo === "bar") {
  console.log("Woah"); // <1>
}
```

1. This is a console output

```c
#include <stdio.h>
int checkPrime(int n);
int main() {
  int n, i, flag = 0;
  printf("Enter a positive integer: ");
  scanf("%d", &n);

  for (i = 2; i <= n / 2; ++i) {                     /* <1> */
    if (checkPrime(i) == 1) {
      if (checkPrime(n - i) == 1) {
        printf("%d = %d + %d\n", n, i, n - i);       /* <2> */
        flag = 1;
      }
    }
  }

  if (flag == 0)
    printf("%d cannot be expressed as the sum of two prime numbers.", n);

  return 0;
}
```

1. Do a barrel roll
2. Print stuff