---
title: "test"
format:
    revealjs:
        footer: "hello world"
_quarto:
  tests:
    revealjs:
      ensureHtmlElements:
        - ["div.footer", "div.footer-default"]
---

## Quarto

Quarto enables you to weave together content and executable code into a finished document. To learn more about Quarto see <https://quarto.org>.

## hiding {visibility="hidden"}

this is a hidden slide.


