---
title: "My Document"
author: "Jane Doe"
toc: true
toc-depth: 2
format:
  html:
    max-width: 800px
    fontsize: 18px
    html-math-method: katex
  pdf:
    documentclass: article
    # microtype introduced a bug preventing reports
    # from being compiled properly
    # https://github.com/schlcht/microtype/issues/3
    # when fixed, switch this back!
    #documentclass: report
    margin-left: 30mm
    margin-right: 30mm
  docx:
    number-sections: true
    reference-docx: mytemplate.docx
---


## Heading

This is a paragraph that is rendered.