---
title: Simple Funding
funding: 
  - statement: "The author(s) received no specific funding for this work."
  - statement: "The author(s) also received no specific funding for this work."
format: jats
---