---
title: float crossref test
format: typst
keep-typ: true
_quarto:
  tests:
    typst:
      ensureTypstFileRegexMatches:
        - 
          - "#ref\\(<fig-1>, supplement: \\[Figure\\]\\)"
          - "#ref\\(<tbl-1>, supplement: \\[Table\\]\\)"
        - []
---

This tests:

- custom content in floats
- classes of float captions

::: {#fig-1}

::: {.figure-content}
This is the figure content.
:::

This is a caption.

:::

See @fig-1.


::: {#tbl-1}

::: {.table-content}
This is the table content.
:::

This is a table.

:::

See @tbl-1.