---
title: Sample Document
author: 
  - id: cteague
    name: Charles Teague
    email: charles@posit.co
    url: https://www.charlesteague.com
    orcid: 0000-0001-8715-9476
    affiliation: 
      name: Posit, PBC
      address: 250 Northern Ave
      city: Boston
      state: MA
      postal-code: 02210
      country: USA
      url: https://www.posit.co
    corresponding: true
    equal-contributor: true
    note: |
      I would like to thank the academy and the screen actor's 
      guild for this distinctive honor.
  - name: Norah Jones
    email: norah@bluenote.com
    equal-contributor: true
    affiliation:
      id: bn-records
      name: Blue Note Records
      address: 2220 Colorado Avenue
      city: Santa Monica
      state: CA
      postal-code: 90404
      country: USA
      url: https://www.bluenote.com
      isni: 0000000122600291
  - name: Albert Einstein
    orcid: 0000-0003-2125-060X
    deceased: true
    affiliation: Princeton University
funding:
  - statement: "Special thanks to sloan foundation and all that."
    open-access: "Miscellaneous text about open access that appears here"
    awards:
      id: award_id_23213
      source:
        - "The Sloan Foundation"
        - text: Cool Source
          country: USA
      recipient:
        - ref: cteague
        - name: Norah Jones
        - institution: Blue Note Records
        - John Hamm
      investigator: 
        - Norah Jones
  - This is another simple statement what is up bro
citation:
  container-id: AGU-SC
  publisher: American Geophysical Union
  publisher-location: Washington, D.C., USA
  container-title: Space Weather
  container-title-short: Space Weather
  eissn: 1542-7390
  type: article-journal
  jats-type: article
  article-id: AGU-identifier
  doi: 10.3352/jeehp.2013.10.3
  subject: Weather in Outer Space
  categories: [space, weather, etc]
  volume: 2
  issue: 3
  page: 45-54
  issued: 1973-05
license:
  - cc by
  - type: "non-commercial"
    url: "https://www.elsevier.com/about/policies/open-access-licenses/elsevier-user-license"
    text: "Elsevier user license"
copyright:
  year: 2022,2020
  statement: ©Copyright; 2022, Charles Teague
  holder: Charles Teague
abstract: |
  In vel luctus ligula, sit amet tincidunt ex. Aliquam erat volutpat. Nullam lacus mauris, luctus ut venenatis quis, vulputate et tellus. Vivamus vulputate cursus risus in placerat. In vel luctus ligula, sit amet tincidunt ex. Aliquam erat volutpat. Nullam lacus mauris, luctus ut venenatis quis, vulputate et tellus. Vivamus vulputate cursus risus in placerat. In vel luctus ligula, sit amet tincidunt ex. Aliquam erat volutpat. Nullam lacus mauris, luctus ut venenatis quis, vulputate et tellus. Vivamus vulputate cursus risus in placerat.
bibliography: bibliography.bib
execute:
  echo: false
keywords: [weather, space, mars]
toc: true
format:
  jats:
    variant: -element_citations
  html: default
  pdf: default
  docx: default
  ipynb: default
_quarto:
  tests:
    jats:
      ensureJatsXpath:
        -
          - '//fig[@id="tbl-stuff"]//table-wrap//table' # table
          - '//fig[@id="tbl-stuff"]//caption'
      ensureFileRegexMatches:
        - 
          - '<!DOCTYPE.*DTD JATS.*' # a JATS DTD must be present
          - '<article-meta>' # basic JATS 
          - '</article-meta>' # basic JATS 
          - '<contrib contrib-type="author" equal-contrib="yes" corresp="yes">' #author
          - '<string-name>Norah Jones</string-name>' #author
          - '<copyright-statement>' #copright metadata
          - '<kwd>weather</kwd>' # keywords
          - '<funding-group>' #funding metadata
          - '<boxed-text>[\s\S]*?<bold>Attention</bold>[\s\S]*?</boxed-text>' # callout
          - '<mixed-citation>' #mixed citation
          - '<xref alt="2013" rid="ref-Schubert13" ref-type="bibr">2013</xref>' #cite
          - '<fig id="fig-line">[\s\S]*?<graphic.*?>[\s\S]*?<\/fig>' # regular figure
          # FIXME: Pandoc doesn't emit position="float"; do we need to?
          # - '<fig id="fig-foobar" position="float">[\s\S]*?<\/fig>' # custom figure div
          - '<fig id="fig-foobar">[\s\S]*?<\/fig>' # custom figure div
        -
          - '<graphic id="fig-line".*/>' # this id should be on the fig element, not the graphic
          - '<boxed-text>\n\s*<boxed-text>' # no nested boxed-text
---

## Introduction {#sec-introduction}

Integer odio velit, gravida ut nunc in, fringilla feugiat justo. Donec eu lorem at ex tristique porttitor id sit amet mauris. Phasellus lacinia sit amet risus vel iaculis. ^[Aenean eget enim ipsum. Proin euismod erat in dolor vehicula elementum.] 

:::{.callout-warning}

## Attention

Pay attention to this callout to read important information that you should attend to. ^[Phasellus at augue feugiat, aliquet enim in, euismod nunc.]

:::

Nulla tempus tincidunt pretium. Aenean eget enim ipsum. Proin euismod erat in dolor vehicula elementum. Aliquam massa erat, bibendum nec sapien in, bibendum sollicitudin augue. Aliquam pretium massa in nibh eleifend, et ullamcorper urna suscipit. Phasellus at augue feugiat, aliquet enim in, euismod nunc. Donec quis nibh eleifend, lobortis nunc a, cursus tortor. See @Schubert13

{{< embed computations.ipynb#fig-line >}}

## Analysis

In vel luctus ligula, sit amet tincidunt ex. Aliquam erat volutpat. Nullam lacus mauris, luctus ut venenatis quis, vulputate et tellus. Vivamus vulputate cursus risus in placerat. Phasellus lobortis velit non dolor semper laoreet. Cras vitae risus nec enim volutpat condimentum sed ac ipsum. Suspendisse ullamcorper eleifend risus sed auctor. Aliquam erat volutpat. [@Girolami05; @aleven_toward_2006]. Also see @sec-introduction.


## Visualization

In vel luctus ligula, sit amet tincidunt ex. Aliquam erat volutpat. Nullam lacus mauris, luctus ut venenatis quis, vulputate et tellus. Vivamus vulputate cursus risus in placerat.

```{r}
#| label: fig-elephant
#| fig-cap: Famous Elephants
plot(cars)
```

In vel luctus ligula, sit amet tincidunt ex. Aliquam erat volutpat. Nullam lacus mauris, luctus ut venenatis quis, vulputate et tellus. Vivamus vulputate cursus risus in placerat. See @fig-elephant.

## Tables

In vel luctus ligula, sit amet tincidunt ex. Aliquam erat volutpat. Nullam lacus mauris, luctus ut venenatis quis, vulputate et tellus. Vivamus vulputate cursus risus in placerat.

```{r}
#| label: tbl-stuff
#| tbl-cap: A table of car related activities.
#| warning: false
library("gt")
knitr::kable(head(mtcars))
```

In vel luctus ligula, sit amet tincidunt ex. Aliquam erat volutpat. Nullam lacus mauris, luctus ut venenatis quis, vulputate et tellus. Vivamus vulputate cursus risus in placerat. See @tbl-stuff.

## Math

In vel luctus ligula, sit amet tincidunt ex. Aliquam erat volutpat. Nullam lacus mauris, luctus ut venenatis quis, vulputate et tellus. Vivamus vulputate cursus risus in placerat.

$$
E_{cell} = E^\circ _{cell} - \frac{{RT}}{{n\Im }}\ln Q = E^\circ _{cell} - \frac{{0.0592}}{n}\log Q
y = mx + b
$$ {#eq-cell-voltage}

In vel luctus ligula, sit amet tincidunt ex. Aliquam erat volutpat. Nullam lacus mauris, luctus ut venenatis quis, vulputate et tellus. Vivamus vulputate cursus risus in placerat. See @eq-cell-voltage.

## Video 

{{< video https://www.youtube.com/embed/wo9vZccmqwc >}}

## Code Listings

```{#lst-customers .sql lst-cap="Customers Query"}
SELECT * FROM Customers
```

Then we query the customers database (@lst-customers).

## Theorems

::: {#thm-line}

## Line

The equation of any straight line, called a linear equation, can be written as:

$$
y = mx + b
$$
:::

See @thm-line.

## Tabsets

::: {.panel-tabset}
## R

```{.r}
fizz_buzz <- function(fbnums = 1:50) {
  output <- dplyr::case_when(
    fbnums %% 15 == 0 ~ "FizzBuzz",
    fbnums %% 3 == 0 ~ "Fizz",
    fbnums %% 5 == 0 ~ "Buzz",
    TRUE ~ as.character(fbnums)
  )
  print(output)
}
```

## Python

```{.python}
def fizz_buzz(num):
  if num % 15 == 0:
    print("FizzBuzz")
  elif num % 5 == 0:
    print("Buzz")
  elif num % 3 == 0:
    print("Fizz")
  else:
    print(num)
```

:::

## Figure Div

:::{#fig-foobar}

A completely custom figure div.

This is a caption for the div
:::


::: {.content-visible when-format="pdf"}

## References {#refs}

:::