---
title: "UA inline image missing alt text"
lang: en
format:
  pdf:
    pdf-standard: ua-2
    keep-tex: true
  typst:
    pdf-standard: ua-1
    keep-typ: true
_quarto:
  tests:
    run:
      # verapdf validation not available on Windows CI
      not_os: windows
    pdf:
      noErrors: default
      ensureLatexFileRegexMatches:
        - ['\\DocumentMetadata\{', 'pdfstandard=\{ua-2\}', 'tagging=on']
        - []
      # NOTE: verapdf passes for ua-2 because LaTeX's tagging=on doesn't create
      # proper structure elements for inline images. This is a LaTeX limitation.
    typst:
      # Typst correctly errors at compile time for missing alt text
      shouldError: default
      printsMessage:
        level: ERROR
        regex: "missing alt text"
---

# Test Document

This inline image has no alt text.

- **Typst**: Correctly errors at compile time ("PDF/UA-1 error: missing alt text")
- **LaTeX**: Warns about missing alt text but tagging=on doesn't create proper
  structure elements for inline images

![](penrose.svg)
