---
title: Branding - Colors
format:
  typst:
    keep-typ: true
_quarto:
  tests:
    typst:
      ensureTypstFileRegexMatches:
        -
          - 'primary: rgb\("#f96302"\),'
          - 'title: (\r\n?|\n)\[(\r\n?|\n)Note(\r\n?|\n)\](\r\n?|\n), (\r\n?|\n)background_color: (\r\n?|\n)brand-color-background.primary'
        -
        -
          - '#set page\(fill: brand-color'
          - '#set text\(fill: brand-color'
---

::: {.callout-note}
This is a `note` callout.
:::

::: {.callout-warning}
This is a `warning` callout.
:::

::: {.callout-important}
This is an `important` callout.
:::

::: {.callout-tip}
This is a `tip` callout.
:::

::: {.callout-caution}
This is a `caution` callout.
:::

