---
title: Test
format: latex
_quarto:
  tests:
    latex:
      ensureFileRegexMatches:
        - ["matplotlib.pyplot"]
        - []
---

```{.python filename="matplotlib.py"}
import matplotlib.pyplot as plt
plt.plot([1,23,2,4])
plt.show()
```
