---
title: Crossref Test
format: html
_quarto:
  tests:
    revealjs:
      ensureHtmlElements:
        - []
#          - "img[src='img/thinker.jpg']" # This appears to not work in deno-dom?!
        - 
          - "a[href='#/fig-elephant1'].quarto-xref"
          - "div#fig-elephant figure.quarto-float-fig figcaption.figure" # because of autostretch, we lose figure elements
---

## Unresolved Crossref Figure

![Elephant](img/thinker.jpg){#fig-elephant}

See @fig-elephant1 for examples. 