---
title: float crossref test
format: revealjs
_quarto:
  tests:
    revealjs:
      ensureHtmlElements:
        - 
          - "div.figure-content"
          - "div.table-content"
          - "figcaption.quarto-float-caption.quarto-float-fig"
          - "figcaption.quarto-float-caption.quarto-float-tbl"
          - "a[href='#/fig-1'].quarto-xref"
          - "a[href='#/tbl-1'].quarto-xref"
        - []
---

This tests:

- custom content in floats
- classes of float captions

::: {#fig-1}

::: {.figure-content}
This is the figure content.
:::

This is a caption.

:::

See @fig-1.


::: {#tbl-1}

::: {.table-content}
This is the table content.
:::

This is a table.

:::

See @tbl-1.