---
title: Listings Test
format: asciidoc
_quarto:
  tests:
    asciidoc:
      ensureFileRegexMatches:
        - 
          - "<<lst-customers>>"
          - "\\[\\[lst-customers\\]\\]"
          - "\\.Customers Query"
---

```{#lst-customers .sql lst-cap="Customers Query"}
SELECT * FROM Customers
```

Then we query the customers database (@lst-customers).