---
title: float test
format: jats
_quarto:
  tests:
    jats:
      ensureJatsXpath:
        - 
          - "//fig[@id=\"fig-foo\"]//caption"
          - "//fig[@id=\"fig-foo\"]//ext-link//inline-graphic[@xlink:href=\"img/surus.jpg\"]"
          - "//fig[@id=\"tbl-foo\"]//caption"
          - "//fig[@id=\"tbl-foo\"]//ext-link//inline-graphic[@xlink:href=\"img/surus.jpg\"]"
          - "//xref[@rid=\"fig-foo\"]"
          - "//xref[@rid=\"tbl-foo\"]"
        - []
---

This tests:

- float syntax for implicit figures and tables as linked images with identifiers

[![This is the figure](img/surus.jpg){#fig-foo}](https://www.example.com/)

[![This is the table](img/surus.jpg){#tbl-foo}](https://www.example.com/)

See @fig-foo and @tbl-foo for more.