---
title: "Issue 11750"
format: html
filters:
  - path: cite
    at: post-quarto
_quarto:
  tests:
    html:
      ensureFileRegexMatches:
        - 
          - '<p><a href="#fig-test" class="quarto-xref">Figure&nbsp;1</a></p>'
          - '<p><a href="https://github.com/mcanouil">@mcanouil</a></p>'
---

::: {#fig-test}
Not a figure

But a caption
:::

@fig-test

@mcanouil
