---
format: html
title: unified light and dark brand inline
brand:
  color:
    foreground: 
      light: '#222'
      dark: '#eee'
    background:
      light: '#eee'
      dark: '#222'
  typography:
    monospace:
      background-color:
        dark: '#321'
    link:
      background-color:
        light: '#efe'
        dark: '#421'
      color:
        dark: '#c3a'
---


```{r}
#| lst-label: lst-fibonacci
#| lst-cap: A naive algorithm for computing Fibonacci numbers.
fib <- function(x) {
  if (x < 2) 1 else fib(x - 1) + fib(x - 2)
}
```

Here is [a link](https://example.com).

{{< lipsum 2 >}}

