---
title: float crossref test
format: latex
_quarto:
  tests:
    latex:
      ensureFileRegexMatches:
        - 
          - "\\\\ref\\{fig-foo\\}"
          - "\\\\ref\\{tbl-foo\\}"
          - "\\\\label\\{fig-foo\\}"
          - "\\\\label\\{tbl-foo\\}"
        - []
---

This tests:

- float syntax for implicit figures and tables as images with identifiers

![This is a figure](img/surus.jpg){#fig-foo}

![This is a table](img/surus.jpg){#tbl-foo}

See @fig-foo and @tbl-foo for more.