---
title: Crossref Test
format: revealjs
_quarto:
  tests:
    revealjs:
      ensureFileRegexMatches:
        -
          - "\\(a\\) Surus"
          - "\\(b\\) Abbas"
      ensureHtmlElements:
        - 
          - "div#fig-elephants figure > figcaption.quarto-float-caption"
          - "div#fig-surus figure.quarto-subfloat-fig figcaption.quarto-subfloat-caption"
          - "div#fig-abbas figure.quarto-subfloat-fig figcaption.quarto-subfloat-caption"
        - []
---

## Simple Sub Figure

::: {#fig-elephants layout-ncol=2}

![Surus](img/surus.jpg){#fig-surus}

![Abbas](img/abbas.jpg){#fig-abbas}

Famous Elephants
:::

See @fig-elephants for examples. In particular, @fig-abbas and @fig-surus. 