---
title: title is `#context text.font`{=typst} `#context text.weight`{=typst} `#context text.style`{=typst} `#context text.size`{=typst}
format:
  typst:
    include-in-header:
      text: |
        #set text(fallback: false)
  html: default
brand: branding/brand.yml
_quarto:
  tests:
    typst:
      ensurePdfRegexMatches:
      -
        - 'title is roboto slab semibold normal 16.5pt'
        - 'heading-2 is roboto slab semibold normal 15.4pt'
        - 'paragraph is open sans regular normal 11pt'
        - 'fib = num => num < 2'
      - []
---

## heading-2 is `#context text.font`{=typst} `#context text.weight`{=typst} `#context text.style`{=typst} `#context text.size`{=typst}

paragraph is `#context text.font`{=typst} `#context text.weight`{=typst} `#context text.style`{=typst} `#context text.size`{=typst}.

```{=typst}
#block(text(font: "Fira Code", weight: "black")[Some text with font set explicitly to #context text.font #context text.weight #context text.style #context text.size])

```

```
const fib = num => num < 2 ? num : fib(num-1) + fib(num - 2);
console.log(fib(12))
```

{{< lipsum 3 >}}

