---
title: "Extension font-paths from subdirectory"
format: font-provider-typst
include-in-header:
  text: |
    #set text(fallback: false)
_quarto:
  tests:
    font-provider-typst:
      printsMessage:
        level: INFO
        regex: 'warning: unknown font family'
        negate: true
---

```{=typst}
#set text(font: "Amaranth")
Testing extension font-paths from a subdirectory.
```
