---
title: Python Subfig Test
_quarto:
  tests:
    docx:
      ensureDocxXpath:
        - 
          - "//w:tbl//w:t[text()=\"(b) Plot 2\"]"
          - "//w:tbl//w:t[text()=\"(a) Plot 1\"]"
          - "//w:t[text()=\"Figure\u00a01: Plots\"]"
        - []
---

## Python Crossref Figure

```{python}
#| label: fig-plots
#| fig-cap: "Plots" 
#| fig-subcap:
#|   - "Plot 1"
#|   - "Plot 2" 
#| layout-ncol: 2

import matplotlib.pyplot as plt
plt.plot([1,23,2,4])
plt.show()

plt.plot([8,65,23,90])
plt.show()
```

See @fig-plots for examples. In particular, @fig-plots-2.