---
title: "Axe False - HTML"
format:
  html:
    axe: false
_quarto:
  tests:
    html:
      ensureHtmlElements:
        - []
        - ['script[src*="axe-check"]', '#quarto-axe-checker-options']
      ensureFileRegexMatches:
        - []
        - ['axe-check\.js', 'quarto-axe-checker-options']
---

## HTML Document

Render with axe: false — no axe dependencies should be present.
