---
title: 4489-exeblocks-lang-value-confluence
format: confluence-publish
validate-yaml: false
_quarto:
  tests:
    html:
      ensureFileRegexMatches:
        -
          - python
---

```{python}
1 + 2
```
