---
title: "Raw TeX cross referencing"
format: 
  pdf: default
---

See @tbl-tex:

```{=latex}
\begin{tabular}{@{}lll@{}}
\label{tbl-tex}
\caption{Some letters with LaTeX}
\toprule
Column 1 & Column 2 & Column 3 \\ \midrule
A        & B        & C        \\
D        & E        & F        \\
G        & H        & I        \\ \bottomrule
\end{tabular}
```
