---
title: Number Sections
format: 
  beamer:
    number-sections: true
keep-tex: true
_quarto:
  tests:
    beamer:
      ensureLatexFileRegexMatches:
        - ['\{1 Section\}', '\{1[.]1 Subsection\}']
        - []
---

## Section

This is the content of the section

### Subsection

This is the content of the subsection